pub struct Git { /* private fields */ }
Git

This struct holds a path to some repository. The path does not need to be root directory of that repository.

Implementations

Makes new instance

If you don’t provide a path, current directory will be used.

Path of this repository

It’s not always the root directory of the repository.